#!/usr/bin/gnuplot

set colors classic
set term x11

set xl "diameter {/Helvetica-Oblique D} / km"
set yl "number of asteroids {/Helvetica-Oblique N}(>{/Helvetica-Oblique D})" offset +0.5

set xr [0.04:1000]
y1=0.8
y2=1.e8
set yr [y1:y2]
set logscale xy
set mxtics 10
set ytics (\
  "1"    1e0,\
  "10"   1e1,\
  "100"  1e2,\
  "1000" 1e3,\
  "10^4" 1e4,\
  "10^5" 1e5,\
  "10^6" 1e6,\
  "10^7" 1e7,\
  "10^8" 1e8 \
  )

set key samplen 1.0
set lmargin 7.2
set rmargin 2.0
set bmargin 3.0
set tmargin 0.7

set style line 5 lt 9 lw 1 pt 1		# observed MB
set style line 3 lt 5 lw 3 pt 1		# initial MB
set style line 1 lt 3 lw 1 pt 1		# evolved MB
set style line 4 lt 8 lw 3 pt 1		# initial family
set style line 2 lt 1 lw 1 pt 1		# evolved family
set style line 6 lt 6 lw 1 pt 1		# initial halo
set style line 7 lt 8 lw 1 pt 1		# evolved halo

p \
  "MB.dat_hc" u 1:2 t "observed MB" w l ls 5,\
  "2_Pallas_family.dat_hc" u 1:2 t "observed Pallas" w l ls 5,\
  "2_Pallas_family.dat_hc" u 1:($2*1.10) not w l ls 5,\
  "2_Pallas_family.dat_hc" u 1:($2*0.90) not w l ls 5,\
  "sph_59.811_12_45_family.dat_hc" u 1:2 t "synthetic Pallas" w l lt 0,\
  "<./hc_sfd.awk sfd1.dat_EDITED" u 1:2 t "initial MB" w l  ls 3,\
  "<./hc_sfd.awk sfd2.dat_EDITED" u 1:2 t "initial family" w l  ls 4,\
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../[0-9]*/tmp/0100.out | ./hc.awk" u 1:2 t "evolved MB" w lp ls 1,\
  "<awk '(FNR==1){ print \"\"; } ($2==2)' ../[0-9]*/tmp/0100.out | ./hc.awk" u 1:2 t "evolved family" w lp ls 2,\

#pa -1

set term post eps enh color solid "Helvetica" 18
set out "sfd_0100.eps"
set size 0.9,0.7
rep


